use crate::constants::USER_ACCESS_TOKEN_ACTIVITY_REFRESH;
use crate::data::user::UserID;
use crate::utils::date_utils::time;

/// User access token information
///
/// Author : Pierre Hubert
#[derive(Debug, Clone)]
pub struct UserAccessToken {
    pub id: u64,
    pub client_id: u64,
    pub user_id: UserID,
    pub token: String,
    pub last_refresh: u64,
    pub timeout: u64,
}

impl UserAccessToken {
    /// Check out whether access token should be refreshed
    pub fn need_refresh(&self) -> bool {
        self.last_refresh + USER_ACCESS_TOKEN_ACTIVITY_REFRESH.as_secs() < time()
    }
}

impl PartialEq<UserAccessToken> for UserAccessToken {
    fn eq(&self, other: &UserAccessToken) -> bool {
        self.id == other.id
    }
}